# Сервис отдачи информации и документов

Сервис отдачи информации и документов (СОИ) - это сервис для доступа к документам, размещенным в единой информационной системе (ЕИС) в сфере закупок [https://zakupki.gov.ru](https://zakupki.gov.ru).

Описание взаимодействия приведено в разделе 2.9.20 документа ЕИС Альбом ТФФ 15 ([ссылка](https://zakupki.gov.ru/epz/main/public/document/view.html?searchString=&sectionId=432&strictEqual=false)).

Данный проект является клиентской библиотекой для взаимодействия с СОИ.

Реализованные методы:
* getNsiRequest – запрос в хранилище документов (ХД) данных справочника
* getDocsByReestrNumberRequest – запрос формирования в ХД архивов с документами по реестровому номеру

## Быстрый старт

Установка

```bash
pip install dars
```

Использование CLI

```bash
dars config edit
# --- загрузить НСИ
dars getnsirequest --base=fz44  --nsicode=nsiOrganization --nsikind=all

# --- Запрос формирования в ХД архивов с документами по реестровому номеру
dars getdocsbyreestrnumberrequest \
  --subsystem-type=PRIZ \
  --reestr-number=0338100003724000064 \
  --prefix=/prefix/in/bucket


Использование модуля

```python
import dars

s3 = {
    "access_key": "key",
    "secret_key": "secret",
    "endpoint_url": "http://localhost:9002",
    "bucket": "drs",
    "region": "ru-1"
}
client = dars.client(sender='myapp', s3=s3)

keys = client.getNsiRequest(
                base='fz44',
                nsicode='nsiOrganization',
                nsikind='all',
		prefix='/fz44/nsi/nsiOrganization'
                )
```

## Типы подсистем

```
Подсистемы 44-ФЗ:
Актуальные значения для передачи:
BTK - Библиотека типовых контрактов;
PRIZ - подсистема размещения извещений (без протоколов со сведениями об участниках);
PRIZP - подсистема размещения извещений (протоколы со сведениями об участниках);
RPEC - подсистема заключения контрактов;
PZKLKP - подсистема заключения контрактов в ЛКП;
RPGZ - реестр планов графиков с 2020 года;
RPNZ - Реестр правил нормирования закупок;
RDI - Реестр дополнительной информации о закупках и контрактах;
RGK - реестр контрактов;
RBG - реестр независимой гарантий;
EA - Электронное актирование;
REC - Реестр электронных контрактов;
RJ - Реестр жалоб;
RPP - Реестр плановых проверок;
RVP - Реестр внеплановых проверок;
RRK - Реестр результатов контроля;
RRA - Реестр результатов аудита;
RNP - Реестр недобросовестных поставщиков;
RKPO - Реестр квалифицированных подрядных организаций;
PPRF615 - Реестр извещений и протоколов 615;
RD615 - Реестр договоров 615;
LKOK - Личный кабинет органа контроля;
OZ - Отчеты заказчика.

Подсистемы 223-ФЗ:
RD223 - Реестр договоров;
RJ223 - Реестр жалоб;
RPP223 - Реестр плановых проверок;
RPZ223 - Реестр планов закупок;
RI223 - Реестр извещений о закупках;
RZ223 - Реестр заказчиков;
OV223 - Информация об объеме выручки;
TPOZ223 - Типовые положения о закупках;
POZ223 - Положения о закупках;
RNP223 - Реестр недобросовестных поставщиков;
POM223 - Подсистема оценки и мониторинга;
RBG223 - Реестр независимых гарантий</xs:documentation>
```

## Обновление от 20.11.2025

Проект dars версии **v1** реализует обмен с сервисом *getDocsMIS2*, который с октября 2024г прекратил свою деятельность.
Вместо него запущен новый сервис *getDocsLE2*. Дальнейшее развитие проекта *dars* будет направлено на реализацию
обмена с  *getDocsLE2* в рамках версии **v2**.

